@@ -43,7 +43,7 @@
 #include <kopeteview.h>
 
 #include "client.h"
-#include <qca.h>
+#include <tqca.h>
 #include "gwcontact.h"
 #include "gwcontactlist.h"
 #include "gwprotocol.h"
